@@ -333,6 +333,11 @@ formatMult <- function(df.in)
     dfnm <- colnames(df.obs)
     nV <- length(dfnm) - 1  # last variable is obsNum
 
+    ### Identify variables that are not factors
+    # Include julian date/visit in search as it is added back in later
+    fac <- sapply(df.obs[, c(3, 5:nV)], is.factor) 
+    nonfac <- names(df.obs[, c(3, 5:nV)])[!fac]
+    
     # create y matrix using reshape
     expr <- substitute(recast(df.obs, var1 ~ year + obsNum + variable,
                               id.var = c(dfnm[2],"year","obsNum"),
@@ -353,6 +358,15 @@ formatMult <- function(df.in)
     y <- as.matrix(y)
 
     obsvars.list <- arrToList(obsvars)
+    
+    # Return any non-factors to the correct mode
+    if (length(nonfac) >= 1) {
+      modes <- apply(df.obs[, nonfac], 2, mode)
+      for (i in 1:length(nonfac)) {
+        mode(obsvars.list[[nonfac[i]]]) <- modes[i]
+      }
+    }
+    
     obsvars.list <- lapply(obsvars.list, function(x) as.vector(t(x)))
     obsvars.df <- as.data.frame(obsvars.list)
 
@@ -409,8 +423,16 @@ formatMult <- function(df.in)
                                                            is.null)])
     if(nrow(yearlySiteCovs) == 0) yearlySiteCovs <- NULL
 
+    # Extract siteCovs and yearlySiteCovs from obsvars
+    finalobsvars.df <- as.data.frame(obsvars.df[, !(names(obsvars.df) %in%
+                                                      c(names(siteCovs),
+                                                        names(yearlySiteCovs)))])
+    names(finalobsvars.df) <- names(obsvars.df)[!(names(obsvars.df) %in% 
+                                                    c(names(siteCovs),
+                                                      names(yearlySiteCovs)))]
+
     umf <- unmarkedMultFrame(y = y, siteCovs = siteCovs,
-                             obsCovs = obsvars.df, yearlySiteCovs =
+                             obsCovs = finalobsvars.df, yearlySiteCovs =
                              yearlySiteCovs,
                              numPrimary = nY)
     return(umf)
@@ -527,58 +549,71 @@ as.numeric(1 - exp(-lambda))
 # Convert individual-level distance data to the
 # transect-level format required by distsamp()
 
-formatDistData <- function(distData, distCol, transectNameCol, dist.breaks,
-                           occasionCol)
+formatDistData <- function (distData, distCol, transectNameCol, dist.breaks, occasionCol,effortMatrix) 
 {
-    if(!is.numeric(distData[,distCol]))
-        stop("The distances must be numeric")
-    transects <- distData[,transectNameCol]
-    if(!is.factor(transects)) {
-        transects <- as.factor(transects)
-        warning("The transects were converted to a factor")
+  if (!is.numeric(distData[, distCol])) 
+    stop("The distances must be numeric")
+  transects <- distData[, transectNameCol]
+  if (!is.factor(transects)) {
+    transects <- as.factor(transects)
+    warning("The transects were converted to a factor")
+  }
+  
+  if (missing(occasionCol)) {
+    T <- 1
+    occasions <- factor(rep(1, nrow(distData)))
+  }
+  else {
+    occasions <- distData[, occasionCol]
+    if (!is.factor(occasions)) {
+      occasions <- as.factor(occasions)
+      warning("The occasions were converted to a factor")
     }
-    if(missing(occasionCol)) {
-        T <- 1
-        occasions <- factor(rep(1, nrow(distData)))
+    T <- nlevels(occasions)
+  }
+  M <- nlevels(transects)
+  J <- length(dist.breaks) - 1
+  if (missing(effortMatrix)) {
+    effortMatrix <- matrix(nrow=M,ncol=T,1)
+  }
+  
+  if (!is.numeric(effortMatrix)){
+    stop("effortMatrix is not numeric")
+    effortMatrix <- matrix(nrow=M,ncol=T,1)
+  }
+  
+  
+  dist.classes <- levels(cut(distData[, distCol], dist.breaks, 
+                             include.lowest = TRUE))
+  ya <- array(NA, c(M, J, T), dimnames = list(levels(transects), 
+                                              dist.classes, paste("rep", 1:T, sep = "")))
+  transect.levels <- levels(transects)
+  occasion.levels <- levels(occasions)
+  for (i in 1:M) {
+    for (t in 1:T) {
+      sub <- distData[transects == transect.levels[i] & 
+                        occasions == occasion.levels[t], , drop = FALSE]
+      ya[i, , t] <- table(cut(sub[, distCol], dist.breaks, 
+                              include.lowest = TRUE))
     }
-    else {
-        occasions <- distData[,occasionCol]
-        if(!is.factor(occasions)) {
-            occasions <- as.factor(occasions)
-            warning("The occasions were converted to a factor")
-        }
-        T <- nlevels(occasions)
-    }
-    M <- nlevels(transects)
-    J <- length(dist.breaks) - 1
-    dist.classes <- levels(cut(distData[,distCol], dist.breaks,
-                               include.lowest=TRUE))
-    ya <- array(NA, c(M, J, T),
-                dimnames = list(levels(transects),
-                                dist.classes,
-                                paste("rep", 1:T, sep="")))
-    transect.levels <- levels(transects)
-    occasion.levels <- levels(occasions)
-    for(i in 1:M) {
-        for(t in 1:T) {
-            sub <- distData[transects==transect.levels[i] &
-                            occasions==occasion.levels[t],,drop=FALSE]
-            ya[i,,t] <- table(cut(sub[,distCol], dist.breaks,
-                                  include.lowest=TRUE))
-        }
-    }
-    y <- matrix(ya, nrow=M, ncol=J*T)
-    dn <- dimnames(ya)
-    rownames(y) <- dn[[1]]
-    if(T==1)
-        colnames(y) <- dn[[2]]
-    else
-        colnames(y) <- paste(rep(dn[[2]],times=T), rep(1:T, each=J), sep="")
-    return(y)
+  }
+  y <- matrix(ya, nrow = M, ncol = J * T)
+  # takes into account the effortMatrix to allow for the insertion of NAs instead of 0s for surveys which were not completed  
+  ee <- array(NA, c(M,length(occasion.levels)*(length(dist.breaks)-1)))
+  for(i in 1:length(occasion.levels)){
+    ee[,((ncol(ee)/length(occasion.levels)*(i-1)+1):(ncol(ee)/length(occasion.levels)*i))] <- matrix(effortMatrix[,i], ncol=J, nrow=M)
+  }
+  ee[ee==0] <- NA
+  y <- y * ee
+  dn <- dimnames(ya)
+  rownames(y) <- dn[[1]]
+  if (T == 1) 
+    colnames(y) <- dn[[2]]
+  else colnames(y) <- paste(rep(dn[[2]], times = T), rep(1:T, each = J), sep = "")
+  return(y)
 }
 
 
-
 ## Sight distance to perpendicular distance
 
 sight2perpdist <- function(sightdist, sightangle)
